# Visitors-and-Corona-Virus-Infected
[![Open in Code Ocean](https://codeocean.com/codeocean-assets/badge/open-in-code-ocean.svg)]([https://codeocean.com/capsule/2389739/tree])

This project compares the number of amusement park visitors with COVID infected people.

Using a newly_confirmed_cases_daily.xlsx and park_visitor.xlsx, VandC is a line graph.

The newly_confirmed_cases_daily.xlsx and park_visitor.xlsx dataset is downloadable from:

https://github.com/ritakei/VisitorsandCOVID/blob/main/newly_confirmed_cases_daily.xlsx
https://github.com/ritakei/VisitorsandCOVID/blob/main/park_visitor.xlsx

The vertical axis is an integer and log display.

<img src='https://github.com/ritakei/VisitorsandCOVID/blob/main/park.png?raw=true' width=640 height=480>

# How to install Visitors-and-Corona-Virus-Infected
You may need some libraries.

$ pip install matplotlib

$ pip install pandas

$ pip install openpyxl

# How to run Visitors-and-Corona-Virus-Infected
The VandC program allows you to plot the number of visitors to amusement parks in Japan and the number of people infected with COVID from January 2020 to March 2022.

$ pip install VisitorsandCOVID

$VisitorsandCOVID

The following command can display a VisitorsandCOVID line graph with.
There are no options.
